" Vim filetype plugin
" Language:	HIP (Heterogeneous-compute Interface for Portability)
" Maintainer:	The Vim Project <https://github.com/vim/vim>
" Last Change:	2026 Jul 15

if exists('b:did_ftplugin')
  finish
endif

" Behaves mostly just like C++
runtime! ftplugin/cpp.vim
