" Vim syntax file
" Language:	none; used to see highlighting
" Maintainer:	github user lacygoill
" Last Change:	2023 Mar 08

" To see your current highlight settings, do
"    :so $VIMRUNTIME/syntax/hitest.vim

import 'dist/vimhighlight.vim'
call vimhighlight.HighlightTest()
